@@ -1,12 +1,15 @@
 package Search::Query::Field::SQL;
-use strict;
-use warnings;
-use base qw( Search::Query::Field );
+use Moo;
+extends 'Search::Query::Field';
 
-__PACKAGE__->mk_accessors(
-    qw( type fuzzy_op fuzzy_not_op is_int ));
+use namespace::sweep;
 
-our $VERSION = '0.25';
+has 'type'         => ( is => 'rw' );
+has 'fuzzy_op'     => ( is => 'rw' );
+has 'fuzzy_not_op' => ( is => 'rw' );
+has 'is_int'       => ( is => 'rw' );
+
+our $VERSION = '0.300';
 
 =head1 NAME
 
@@ -29,7 +32,7 @@ validation and aliasing in SQL search queries.
 This class is a subclass of Search::Query::Field. Only new or overridden
 methods are documented here.
 
-=head2 init
+=head2 BUILD
 
 Available params are also standard attribute accessor methods.
 
@@ -51,9 +54,8 @@ Set if C<type> matches m/int|float|bool|time|date/.
 
 =cut
 
-sub init {
+sub BUILD {
     my $self = shift;
-    $self->SUPER::init(@_);
 
     $self->{type} ||= 'char';
 
